@@ -45,7 +45,7 @@ import time
 def subscribe(url):
     """ subscribe to an hubbub feed. """
     subscribe_args = {
-        'hub.callback': urllib.parse.urljoin('https://jsonbot.appspot.com', '/hubbub'),
+        'hub.callback': urllib.parse.urljoin('https://fbfbot.appspot.com', '/hubbub'),
         'hub.mode': 'subscribe',
         'hub.topic': url,
         'hub.verify': 'async',
@@ -501,20 +501,6 @@ def handle_hubbubclone(bot, event):
 cmnds.add('hb-clone', handle_hubbubclone, 'USER')
 examples.add('hb-clone', 'clone feeds into new channel', 'hb-clone #dunkbots')
 
-## hb-cloneurl command
-
-def handle_hubbubcloneurl(bot, event):
-    """ arguments: <url> - clone urls from http://host/feeds. """
-    if not event.rest: event.missing('<url>') ; return
-    import urllib.request, urllib.error, urllib.parse
-    try:
-        feeds = watcher.cloneurl(event.rest, event.auth)
-        event.reply('cloned the following feeds: ', feeds)
-    except urllib.error.HTTPError as ex: event.reply("hubbub - clone - %s" % str(ex))
-
-cmnds.add('hb-cloneurl', handle_hubbubcloneurl, 'OPER')
-examples.add('hb-cloneurl', 'clone feeds from remote url', 'hb-cloneurl http://jsonbot.org/feeds')
-
 ## hb-add command
 
 def handle_hubbubadd(bot, ievent):
